<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 * @return array An array of default values
 */

function blogable_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$blogable_default_options = array(
		// Color Options
		'header_title_color'			    => '#fff',
		'header_tagline_color'			    => '#fff',
		'header_txt_logo_extra'			    => 'show-all',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,
		'read_more_text'           		    => esc_html__( 'Read More', 'blogable' ),

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'blogable' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,featured_post,popular_post,promotion,blog,stories',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'blogable' ),
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) false,
		'slider_count'						=> 3,
		'slider_btn_txt'                    => esc_html__('Learn More','blogable'),

		// featured_post
		'featured_post_section_enable'			=> (bool) false,
		'featured_post_count'					=> 3,
		
		//popular_post 
		'popular_post_section_enable'		   => (bool) false,
		'popular_post_count'				   => 3,
		
		// blog
		'blog_section_enable'			    => (bool) false,
		'blog_title'					    => esc_html__( 'From Our Blogs', 'blogable' ),
		'blog_sub_title'          			=> esc_html__('Latest Articles','blogable'),
		'blog_count'					    => 3,

		// stories
		'stories_section_enable'		    => (bool) false,
		'stories_title'					    => esc_html__( 'Adventure & Travel', 'blogable' ),
		'stories_sub_title'          		=> esc_html__('Popular Stories','blogable'),
		'stories_count'					    => 3,
		'stories_read_more_btn_label'	    => esc_html__( 'Read More', 'blogable' ),

		//promotion
		'promotion_section_enable' 		=> (bool) false,
		'promotion_read_more'			=>	esc_html__('Contact Us', 'blogable'),
		
	);

	$output = apply_filters( 'blogable_default_theme_options', $blogable_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}