<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage  Blogable
 * @since  Blogable 1.0.0
 */
if ( ! function_exists( 'blogable_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since  Blogable 1.0.0
    */
    function blogable_add_slider_section() {
    	$options = blogable_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'blogable_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'blogable_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        blogable_render_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'blogable_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since  Blogable 1.0.0
    * @param array $input slider section details.
    */
    function blogable_get_slider_section_details( $input ) {
        $options = blogable_get_theme_options();
        $slider_count           = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 4;
        $content = array();

        $page_ids = array();

        for ( $i = 1; $i <= $slider_count; $i++ ) {
            if ( ! empty( $options['slider_content_page_' . $i] ) )
                $page_ids[] = $options['slider_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $slider_count ),
            'orderby'           => 'post__in',
        );                    

           
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blogable_trim_content(25);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'blogable_filter_slider_section_details', 'blogable_get_slider_section_details' );


if ( ! function_exists( 'blogable_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since  Blogable 1.0.0
   *
   */
   function blogable_render_slider_section( $content_details = array() ) {
        $options = blogable_get_theme_options();
        $slider_btn_alt_url = (!empty($options['slider_btn_alt_url'])) ? $options['slider_btn_alt_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="blogable_slider_section">
            <div id="featured-slider-section" class="slider-section">
                <div class="featured-slider"
                    data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows": false, "autoplay": true, "draggable": true, "fade": false, "adaptiveHeight": true, "fade": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                    <article style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="featured-content-wrapper">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                        </h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if( !empty($options['slider_btn_txt']) ): ?>
                                    <div class="read-more">
                                        <?php if(!empty($options['slider_btn_txt'])): ?>
                                            <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['slider_btn_txt']); ?></a>
                                        <?php endif; ?>
                                    </div><!-- .read-more -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-content-wrapper -->
                        </div><!-- .wrapper -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .featured-slider -->
            </div><!-- #featured-slider-section -->
        </div>
      

<?php
    }    
endif;